mood.test: Mood Test

mood.testR Documentation

Mood Test

Description

mood.test performs Mood variance homogeneity test.

Usage

mood.test(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) 

Arguments

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

data

a tibble or data frame containing the variables in formula.

alpha

the level of significance to assess variance homogeneity. Default is set to alpha = 0.05.

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

verbose

a logical for printing output to R console.

Details

Prior to testing for variance homogeneity, the data within each group are centered by their corresponding group median to eliminate the confounding effects of location parameters (Conover et al., 1981).

Value

A list with class "vht" containing the following components:

statistic

the corresponding test statistic.

parameter

the parameter(s) of the approximate chi-squared distribution of the test statistic.

p.value

the p-value of the test.

method

the character string "Mood Test".

data

a data frame containing the variables in which NA values (if exist) are removed.

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

Author(s)

Gozde Cosar and Osman Dag

References

Conover, W.J., Johnson, M.E., Johnson, M.M. (1981). A Comparative Study of Tests for Homogeneity of Variances, with Applications to the Outer Continental Shelf Bidding Data. Technometrics, 23:4, 351-361.

Mood, A.M. (1954). On the Asymptotic Efficiency of Certain Nonparametric Two-Sample Tests. The Annals of Mathematical Statistics, 25:3, 514-522.

See Also

mood_test

Examples


library(vartest)

mood.test(Sepal.Length ~ Species, data = iris)

out <- mood.test(Sepal.Length ~ Species, data = iris)
summary(out)

vartest documentation built on April 22, 2026, 5:09 p.m.

Related to mood.test in vartest...