Learn R Programming

vartest (version 1.3)

print.summary.vht: Print Method for Summary of Variance Homogeneity Test Results

Description

Prints the formatted summary of a vht object to the console.

Usage

# S3 method for summary.vht
print(x, ...)

Arguments

x

An object returned by summary.vht().

...

Additional arguments.

Author

Merve Kasikci, Osman Dag

See Also

summary.vht

Examples

Run this code
out <- bartletts.test(Sepal.Length ~ Species, data = iris, verbose = FALSE)
summary(out)

Run the code above in your browser using DataLab