Learn R Programming

vartest (version 1.3)

siegel.tukey.test: Siegel Tukey Test

Description

siegel.tukey.test performs Siegel Tukey variance homogeneity test.

Usage

siegel.tukey.test(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE)

Value

A list with class "vht" containing the following components:

statistic

the corresponding test statistic.

parameter

the parameter(s) of the approximate chi-squared distribution of the test statistic.

p.value

the p-value of the test.

method

the character string "Siegel Tukey Test".

data

a data frame containing the variables in which NA values (if exist) are removed.

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

Arguments

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

data

a tibble or data frame containing the variables in formula.

alpha

the level of significance to assess variance homogeneity. Default is set to alpha = 0.05.

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

verbose

a logical for printing output to R console.

Author

Gozde Cosar and Osman Dag

References

Gibbons, J.D., Chakraborti, S. (2010). Nonparametric Statistical Inference. CRC Press, 5th Ed., 316-320.

Siegel, S., Tukey, J.W. (1960). A Nonparametric Sum of Ranks Procedure for Relative Spread in Unpaired Samples. Journal of the American Statistical Association, 55:291, 429-445.

See Also

GSTTest

Examples

Run this code

library(vartest)

siegel.tukey.test(Sepal.Length ~ Species, data = iris)

out <- siegel.tukey.test(Sepal.Length ~ Species, data = iris)
summary(out)

Run the code above in your browser using DataLab