talwar.gentle.test: Talwar and Gentle Test

talwar.gentle.testR Documentation

Talwar and Gentle Test

Description

talwar.gentle.test performs Talwar and Gentle variance homogeneity test.

Usage

talwar.gentle.test(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) 

Arguments

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

data

a tibble or data frame containing the variables in formula.

alpha

the level of significance to assess variance homogeneity. Default is set to alpha = 0.05.

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

verbose

a logical for printing output to R console.

Details

Prior to testing for variance homogeneity, the data within each group are centered by their corresponding group median to eliminate the confounding effects of location parameters (Conover et al., 1981).

Value

A list with class "vht" containing the following components:

statistic

the corresponding test statistic.

parameter

the parameter(s) of the approximate chi-squared distribution of the test statistic.

p.value

the p-value of the test.

method

the character string "Talwar and Gentle Test".

data

a data frame containing the variables in which NA values (if exist) are removed.

formula

a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.

Author(s)

Gozde Cosar and Osman Dag

References

Conover, W.J., Johnson, M.E., Johnson, M.M. (1981). A Comparative Study of Tests for Homogeneity of Variances, with Applications to the Outer Continental Shelf Bidding Data. Technometrics, 23:4, 351-361.

Talwar, P.P., Gentle, J.E. (1976). A Robust Test for the Homogeneity of Scales. Communications in Statistics - Theory and Methods, 6:4, 363-369.

Examples


library(vartest)

talwar.gentle.test(Sepal.Length ~ Species, data = iris)

out <- talwar.gentle.test(Sepal.Length ~ Species, data = iris, verbose = FALSE)
summary(out)

vartest documentation built on April 22, 2026, 5:09 p.m.