View source: R/select_vartest.R
| select_vartest | R Documentation |
select_vartest performs an automated, simulation-based evaluation to identify the optimal variance homogeneity test for a dataset.
select_vartest(formula, data, nrep = 1000, alpha = 0.05, na.rm = TRUE, verbose = TRUE)
formula |
a formula of the form |
data |
a tibble or data frame containing the variables in |
nrep |
an integer specifying the number of Monte Carlo replications to perform for the simulation. The default is |
alpha |
the level of significance to assess variance homogeneity. Default is set to alpha = 0.05. |
na.rm |
a logical value indicating whether NA values should be stripped before the computation proceeds. |
verbose |
a logical for printing output to R console. |
The function calculates the empirical moments of the input data and uses the Pearson distribution system to generate random datasets. By evaluating 28 distinct methodological modifications of variance homogeneity tests on these generated datasets, the function recommends the method that yields the highest adjusted power (with the lowest Type I error).
A data frame presenting empirical power, Type I error rate, and adjusted power for each variance homogeneity test.
Muhammed Ali Yilmaz and Osman Dag
library(vartest)
out <- select_vartest(Sepal.Length ~ Species, data = iris, nrep = 1000)
out
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.