powered by
siegel.tukey.test performs Siegel Tukey variance homogeneity test.
siegel.tukey.test
siegel.tukey.test(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE)
A list with class "vht" containing the following components:
the corresponding test statistic.
the parameter(s) of the approximate chi-squared distribution of the test statistic.
the p-value of the test.
the character string "Siegel Tukey Test".
a data frame containing the variables in which NA values (if exist) are removed.
a formula of the form lhs ~ rhs where lhs gives the sample values and rhs the corresponding groups.
lhs ~ rhs
lhs
rhs
a tibble or data frame containing the variables in formula.
formula
the level of significance to assess variance homogeneity. Default is set to alpha = 0.05.
a logical value indicating whether NA values should be stripped before the computation proceeds.
a logical for printing output to R console.
Gozde Cosar and Osman Dag
Gibbons, J.D., Chakraborti, S. (2010). Nonparametric Statistical Inference. CRC Press, 5th Ed., 316-320.
Siegel, S., Tukey, J.W. (1960). A Nonparametric Sum of Ranks Procedure for Relative Spread in Unpaired Samples. Journal of the American Statistical Association, 55:291, 429-445.
GSTTest
library(vartest) siegel.tukey.test(Sepal.Length ~ Species, data = iris) out <- siegel.tukey.test(Sepal.Length ~ Species, data = iris) summary(out)
Run the code above in your browser using DataLab